@@ -4,5 +4,9 @@
 #' @import ggplot2
 #' @importFrom utils head
 #' @importFrom graphics plot
-#' @importFrom stats sd
+#' @importFrom stats sd as.dendrogram
 "_PACKAGE"
+
+.onLoad = function(libname, pkgname) {
+  utils::globalVariables(c("modname", "count"))
+}
