@@ -7,7 +7,7 @@ skip_if_not_installed("ggfortify")
 test_that("autoplot.LearnerRegrGlmnet", {
   requireNamespace("mlr3learners")
   learner = mlr3::lrn("regr.glmnet")$train(mlr3::tsk("mtcars"))
-  p = autoplot(learner)
+  p = autoplot(learner, type = "ggfortify")
   expect_true(is.ggplot(p))
   expect_doppelganger("learner_regr.glmnet", p)
 })
